@@ -1,4 +1,4 @@
-# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015,2016 Hewlett Packard Enterprise Development LP
 
 import ntplib
 
@@ -22,11 +22,12 @@ class NtpCheck(AgentCheck):
             'version': int(instance.get('version', DEFAULT_NTP_VERSION)),
             'timeout': float(instance.get('timeout', DEFAULT_TIMEOUT)),
         }
+        dimensions['ntp_server'] = req_args['host']
         try:
             ntp_stats = ntplib.NTPClient().request(**req_args)
-        except ntplib.NTPException:
-            self.log.error("Could not connect to NTP Server")
-            raise
+        except ntplib.NTPException as err:
+            self.log.error("Could not connect to NTP Server: %s" % err)
+            self.gauge('ntp.connection_status', 1, dimensions=dimensions)
         else:
             ntp_offset = ntp_stats.offset
 
@@ -34,3 +35,4 @@ class NtpCheck(AgentCheck):
             # case the agent host's clock is messed up.
             ntp_ts = ntp_stats.recv_time
             self.gauge('ntp.offset', ntp_offset, timestamp=ntp_ts, dimensions=dimensions)
+            self.gauge('ntp.connection_status', 0, timestamp=ntp_ts, dimensions=dimensions)
