@@ -1,4 +1,5 @@
 # (c) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
+# Copyright 2017 SUSE Linux GmbH
 
 import ConfigParser
 import grp
@@ -12,6 +13,7 @@ import sys
 from monasca_agent.common.psutil_wrapper import psutil
 import monasca_setup.agent_config
 from monasca_setup.detection import Plugin
+from monasca_setup.detection import utils
 
 
 log = logging.getLogger(__name__)
@@ -53,12 +55,7 @@ class Libvirt(Plugin):
     def _detect(self):
         """Set self.available True if the process and config file are detected
         """
-        # Detect Agent's OS username by getting the group owner of confg file
-        try:
-            gid = os.stat('/etc/monasca/agent/agent.yaml').st_gid
-            self.agent_user = grp.getgrgid(gid)[0]
-        except OSError:
-            self.agent_user = None
+        self.agent_user = utils.get_agent_username()
         # Try to detect the location of the Nova configuration file.
         # Walk through the list of processes, searching for 'nova-compute'
         # process with 'nova.conf' inside one of the parameters
@@ -93,19 +90,11 @@ class Libvirt(Plugin):
             nova_cfg.read(self.nova_conf)
             # Which configuration options are needed for the plugin YAML?
             # Use a dict so that they can be renamed later if necessary
-            cfg_needed = {'admin_user': 'admin_user',
-                          'admin_password': 'admin_password',
-                          'admin_tenant_name': 'admin_tenant_name'}
+            cfg_needed = {'username': 'username',
+                          'password': 'password',
+                          'project_name': 'project_name'}
             cfg_section = 'keystone_authtoken'
 
-            # Handle Devstack's slightly different nova.conf names
-            if (nova_cfg.has_option(cfg_section, 'username')
-               and nova_cfg.has_option(cfg_section, 'password')
-               and nova_cfg.has_option(cfg_section, 'project_name')):
-                cfg_needed = {'admin_user': 'username',
-                              'admin_password': 'password',
-                              'admin_tenant_name': 'project_name'}
-
             # Start with plugin-specific configuration parameters
             init_config = {'cache_dir': cache_dir,
                            'nova_refresh': nova_refresh,
@@ -128,9 +117,9 @@ class Libvirt(Plugin):
 
             # Create an identity URI (again, slightly different for Devstack)
             if nova_cfg.has_option(cfg_section, 'auth_url'):
-                init_config['identity_uri'] = "{0}/v2.0".format(nova_cfg.get(cfg_section, 'auth_url'))
+                init_config['auth_url'] = nova_cfg.get(cfg_section, 'auth_url')
             else:
-                init_config['identity_uri'] = "{0}/v2.0".format(nova_cfg.get(cfg_section, 'identity_uri'))
+                init_config['auth_url'] = nova_cfg.get(cfg_section, 'identity_uri')
 
             # Verify requirements to enable ping checks
             init_config['ping_check'] = self.literal_eval('False')
